export declare const defaultSocialiteNetworks: SocialiteNetwork[];

export declare const defaultUserMatcher: {
    subdomain: RegExp;
    path: RegExp;
};

export declare interface DiscordUrlCriteria {
    tldomain?: UrlAnatomy['tldomain'];
    path?: UrlAnatomy['path'];
    user?: UserName;
}

export declare function filterNetworkProperties(network: SocialiteNetwork, subset: SocialiteNetworkProperties): Partial<SocialiteNetwork>;

export declare function getDiscordPreferredUrl({ tldomain, path, user, }: DiscordUrlCriteria): string;

export declare function getUrlGroups(url?: string): ParsedUrlGroups;

export declare function getUrlWithSubstitutions(url?: string, user?: string, prefix?: string): string;

export declare enum MatchUserSource {
    Subdomain = "subdomain",
    Path = "path"
}

declare interface MergedRegExp {
    source: RegExp['source'];
    flags: RegExp['flags'];
}

export declare function mergeRegExp(...expressions: RegExp[]): MergedRegExp;

declare type NetworkId = string;

declare type NetworkMap = Map<NetworkId, SocialiteNetwork>;

declare interface NetworkMatcher {
    domain: string | RegExp;
    userSource?: MatchUserSource;
    user?: string | RegExp;
}

declare type ParsedUrlGroups = UrlGroupSubset | null;

export declare const profileReplacement: {
    user: string;
    prefix: string;
};

export declare const schemeRegExp: RegExp;

export declare class Socialite {
    #private;
    constructor(customNetworks?: SocialiteNetwork[]);
    hasNetwork(id?: string): boolean;
    addNetwork(network: SocialiteNetwork, overwrite?: boolean): false | NetworkMap;
    removeNetwork(id?: string): boolean;
    emptyNetworks(): void;
    getNetwork(id?: string): SocialiteNetwork | undefined;
    getAllNetworks(subset?: SocialiteNetworkProperties): Partial<SocialiteNetwork>[];
    getNetworkFromDomain(domain?: string): SocialiteNetwork | undefined;
    getPreferredUrl(id?: string, user?: string): string | false;
    parseUrl(url?: string): false | UrlAnatomy;
    parseProfile(value: string | UrlAnatomy, id?: string): false | SocialiteProfile;
    fixUrlScheme(url?: string): string;
    mergeGroupsToUrl(groups: UrlAnatomy): string;
}

export declare type SocialiteId = keyof typeof socialiteNetworks;

export declare interface SocialiteNetwork {
    id: NetworkId;
    matcher: NetworkMatcher;
    preferredUrl: string;
    appUrl?: string;
    prefix?: UserPrefix;
}

export declare type SocialiteNetworkProperties = SocialiteNetworkProperty[];

declare type SocialiteNetworkProperty = keyof SocialiteNetwork;

export declare const socialiteNetworks: {
    behance: SocialiteNetwork;
    devto: SocialiteNetwork;
    discord: SocialiteNetwork;
    dribbble: SocialiteNetwork;
    exercism: SocialiteNetwork;
    facebook: SocialiteNetwork;
    github: SocialiteNetwork;
    instagram: SocialiteNetwork;
    keybase: SocialiteNetwork;
    linkedin: SocialiteNetwork;
    medium: SocialiteNetwork;
    onlyfans: SocialiteNetwork;
    patreon: SocialiteNetwork;
    pinterest: SocialiteNetwork;
    reddit: SocialiteNetwork;
    stackoverflow: SocialiteNetwork;
    substack: SocialiteNetwork;
    telegram: SocialiteNetwork;
    tiktok: SocialiteNetwork;
    twitch: SocialiteNetwork;
    twitter: SocialiteNetwork;
    vimeo: SocialiteNetwork;
    yat: SocialiteNetwork;
    youtube: SocialiteNetwork;
};

export declare const socialitePrefix: {
    medium: string;
    tiktok: string;
    twitter: string;
};

export declare interface SocialiteProfile {
    id: NetworkId;
    urlGroups: UrlAnatomy;
    originalUrl: string;
    preferredUrl: string;
    appUrl?: string;
    user?: UserName;
    prefix?: UserPrefix;
}

export declare interface UrlAnatomy {
    domain: string;
    tldomain: string;
    scheme?: string;
    subdomain?: string;
    port?: string;
    path?: string;
    parameters?: string;
    anchor?: string;
}

export declare const urlCaptureGroup: {
    scheme: string;
    domain: string;
    tldomain: string;
    port: string;
    path: string;
    parameters: string;
    anchor: string;
};

export declare enum UrlCaptureId {
    Scheme = "scheme",
    Domain = "domain",
    Tldomain = "tldomain",
    Port = "port",
    Path = "path",
    Parameters = "parameters",
    Anchor = "anchor"
}

declare type UrlGroupSubset = Partial<UrlAnatomy>;

export declare const urlRegExp: RegExp;

declare type UserName = string;

declare type UserPrefix = string;

export { }
